@@ -1,10 +1,10 @@
 """
 This section covers the interface for `NERDA` models, that is 
-implemented as its own Python class [NERDA.models.NERDA][NERDA].
+implemented as its own Python class [NERDA.models.NERDA][].
 
 The interface enables you to easily 
 
-- specify your own [NERDA.models.NERDA][NERDA] model
+- specify your own [NERDA.models.NERDA][] model
 - train it
 - evaluate it
 - use it to predict entities in new texts.
@@ -41,7 +41,7 @@ class NERDA:
         >>> tag_scheme = ['B-PER', 'I-PER' 'B-LOC', 'I-LOC',
                           'B-ORG', 'I-ORG', 'B-MISC, 'I-MISC']
         >>> tag_outside = 'O'
-        >>> transformer = 'bert-base-multilingual-uncased',
+        >>> transformer = 'bert-base-multilingual-uncased'
         >>> model = NERDA(transformer = transformer,
                           tag_scheme = tag_scheme,
                           tag_outside = tag_outside,
@@ -51,7 +51,7 @@ class NERDA:
         Model for complete English NER data set CoNLL-2003 with modified hyperparameters
         >>> trn = get_conll_data('train')
         >>> valid = get_conll_data('valid')
-        >>> transformer = 'bert-base-multilingual-uncased',
+        >>> transformer = 'bert-base-multilingual-uncased'
         >>> hyperparameters = {'epochs' : 3,
                                'warmup_steps' : 400,
                                'train_batch_size': 16,
@@ -260,7 +260,7 @@ class NERDA:
                 'batch_size' and 'num_workers'.
 
         Returns:
-            List with word-tokenized sentences and predicted 
+            tuple: word-tokenized sentences and predicted 
             tags/entities.
         """
         return predict_text(network = self.network, 
